# Generated by roxygen2: do not edit by hand

export(bs_theme_esquisse)
export(build_aes)
export(colorPicker)
export(downloads_labels)
export(dragulaInput)
export(dropInput)
export(esquisseContainer)
export(esquisse_container)
export(esquisse_header)
export(esquisse_server)
export(esquisse_ui)
export(esquisser)
export(ggcall)
export(ggplot_output)
export(ggplot_to_ppt)
export(i18n)
export(match_geom_args)
export(palettePicker)
export(ph)
export(potential_geoms)
export(potential_geoms_ref)
export(render_ggplot)
export(safe_ggplot)
export(save_ggplot_modal)
export(save_ggplot_server)
export(save_ggplot_ui)
export(set_i18n)
export(updateColorPicker)
export(updateDragulaInput)
export(updateDropInput)
export(updatePalettePicker)
export(which_pal_scale)
import(ggplot2)
importFrom(bslib,accordion)
importFrom(bslib,accordion_panel)
importFrom(bslib,bs_add_rules)
importFrom(bslib,bs_theme)
importFrom(bslib,layout_sidebar)
importFrom(bslib,nav_panel)
importFrom(bslib,nav_panel_hidden)
importFrom(bslib,nav_select)
importFrom(bslib,navset_hidden)
importFrom(bslib,navset_pill)
importFrom(bslib,sidebar)
importFrom(datamods,cut_variable_server)
importFrom(datamods,cut_variable_ui)
importFrom(datamods,filter_data_server)
importFrom(datamods,filter_data_ui)
importFrom(datamods,i18n)
importFrom(datamods,import_modal)
importFrom(datamods,import_server)
importFrom(datamods,set_i18n)
importFrom(datamods,show_data)
importFrom(datamods,update_variables_server)
importFrom(datamods,update_variables_ui)
importFrom(ggplot2,"%+%")
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,ggplot_gtable)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_color_distiller)
importFrom(ggplot2,scale_color_gradient)
importFrom(ggplot2,scale_color_hue)
importFrom(ggplot2,scale_color_viridis_c)
importFrom(ggplot2,scale_color_viridis_d)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_fill_distiller)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_hue)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(ggplot2,scale_fill_viridis_d)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_dark)
importFrom(ggplot2,theme_gray)
importFrom(ggplot2,theme_grey)
importFrom(ggplot2,theme_light)
importFrom(ggplot2,theme_linedraw)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,vars)
importFrom(grDevices,cairo_pdf)
importFrom(grDevices,colorRampPalette)
importFrom(htmltools,HTML)
importFrom(htmltools,css)
importFrom(htmltools,doRenderTags)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,singleton)
importFrom(htmltools,tag)
importFrom(htmltools,tagAppendAttributes)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmltools,validateCssUnit)
importFrom(jsonlite,base64_enc)
importFrom(jsonlite,toJSON)
importFrom(phosphoricons,ph)
importFrom(rlang,as_name)
importFrom(rlang,call2)
importFrom(rlang,eval_tidy)
importFrom(rlang,expr)
importFrom(rlang,has_length)
importFrom(rlang,has_name)
importFrom(rlang,have_name)
importFrom(rlang,is_call)
importFrom(rlang,is_list)
importFrom(rlang,is_named)
importFrom(rlang,parse_expr)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(rstudioapi,getSourceEditorContext)
importFrom(rstudioapi,insertText)
importFrom(rstudioapi,isAvailable)
importFrom(scales,brewer_pal)
importFrom(scales,hue_pal)
importFrom(scales,seq_gradient_pal)
importFrom(scales,viridis_pal)
importFrom(shiny,NS)
importFrom(shiny,actionButton)
importFrom(shiny,actionLink)
importFrom(shiny,addResourcePath)
importFrom(shiny,bindEvent)
importFrom(shiny,browserViewer)
importFrom(shiny,callModule)
importFrom(shiny,checkboxInput)
importFrom(shiny,column)
importFrom(shiny,conditionalPanel)
importFrom(shiny,debounce)
importFrom(shiny,dialogViewer)
importFrom(shiny,downloadButton)
importFrom(shiny,downloadHandler)
importFrom(shiny,downloadLink)
importFrom(shiny,exprToFunction)
importFrom(shiny,fillCol)
importFrom(shiny,fillPage)
importFrom(shiny,fillRow)
importFrom(shiny,fluidRow)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,icon)
importFrom(shiny,is.reactive)
importFrom(shiny,is.reactivevalues)
importFrom(shiny,isTruthy)
importFrom(shiny,isolate)
importFrom(shiny,modalDialog)
importFrom(shiny,moduleServer)
importFrom(shiny,numericInput)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,paneViewer)
importFrom(shiny,plotOutput)
importFrom(shiny,radioButtons)
importFrom(shiny,reactive)
importFrom(shiny,reactiveValues)
importFrom(shiny,reactiveValuesToList)
importFrom(shiny,registerInputHandler)
importFrom(shiny,renderPlot)
importFrom(shiny,renderUI)
importFrom(shiny,req)
importFrom(shiny,restoreInput)
importFrom(shiny,runGadget)
importFrom(shiny,selectInput)
importFrom(shiny,showModal)
importFrom(shiny,showNotification)
importFrom(shiny,sliderInput)
importFrom(shiny,splitLayout)
importFrom(shiny,stopApp)
importFrom(shiny,textInput)
importFrom(shiny,uiOutput)
importFrom(shiny,updateSliderInput)
importFrom(shiny,updateTextInput)
importFrom(shinyWidgets,alert)
importFrom(shinyWidgets,colorPickr)
importFrom(shinyWidgets,dropMenu)
importFrom(shinyWidgets,dropdown)
importFrom(shinyWidgets,hideDropMenu)
importFrom(shinyWidgets,numericInputIcon)
importFrom(shinyWidgets,numericRangeInput)
importFrom(shinyWidgets,pickerInput)
importFrom(shinyWidgets,prettyCheckbox)
importFrom(shinyWidgets,prettyCheckboxGroup)
importFrom(shinyWidgets,prettyRadioButtons)
importFrom(shinyWidgets,prettySwitch)
importFrom(shinyWidgets,prettyToggle)
importFrom(shinyWidgets,progressBar)
importFrom(shinyWidgets,radioGroupButtons)
importFrom(shinyWidgets,textInputIcon)
importFrom(shinyWidgets,updateNumericInputIcon)
importFrom(shinyWidgets,updatePickerInput)
importFrom(shinyWidgets,updatePrettyCheckboxGroup)
importFrom(shinyWidgets,updateProgressBar)
importFrom(shinyWidgets,virtualSelectInput)
importFrom(stats,setNames)
importFrom(tools,toTitleCase)
importFrom(utils,browseURL)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
